<?php

/*********************************************************************************

 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2

 * ("License"); You may not use this file except in compliance with the

 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL

 * Software distributed under the License is distributed on an  "AS IS"  basis,

 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for

 * the specific language governing rights and limitations under the License.

 * The Original Code is:  SugarCRM Open Source

 * The Initial Developer of the Original Code is SugarCRM, Inc.

 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;

 * All Rights Reserved.

 * Contributor(s): ______________________________________.

 ********************************************************************************/

/*********************************************************************************

 * $Header: /advent/projects/custprojects/vtigercrm/vtigersupport/vtiger_crm/modules/Settings/language/en_us.lang.php,v 1.2 2007/07/06 09:55:40 rajeshkannan Exp $

 * Description:  Defines the English language pack

 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.

 * All Rights Reserved.

 * Contributor(s): ______________________________________..

 ********************************************************************************/



$mod_strings = Array(

'LBL_MODULE_NAME'=>'Settings',

'LBL_MODULE_TITLE'=>'Settings: Home',

'LBL_LIST_CONTACT_ROLE'=>'Role',



'LBL_LIST_LAST_NAME'=>'Last Name',

'LBL_FIRST_NAME'=>'First Name:',

'LBL_LAST_NAME'=>'Last Name:',

'LBL_PHONE'=>'Phone:',

'LBL_EMAIL_ADDRESS'=>'Email',

'LBL_TRANSCURR'=>'Transfer currency to',

'LBL_CURRDEL'=>'Currency to be Deleted',

'LBL_NEW_FORM_TITLE'=>'New Contact',

'LBL_NEW_CURRENCY'=>'New Currency',

'LBL_VIEWING'=>'Viewing',

'LBL_CURRENCY_NAME'=>'Currency Name',

'LBL_CURRENCY_CODE'=>'Currency Code',

'LBL_CURRENCY_SYMBOL'=>'Symbol',

'LBL_CURRENCY_CRATE'=>'Conversion Rate',

'LBL_CURRENCY_STATUS'=>'Status',

'LBL_CURRENCY_TOOL'=>'Tools',

'LBL_CURRENCY_LIST'=>'Currencies List',


'NTC_DELETE_CONFIRMATION'=>'Are you sure you want to delete this record?',

'LEADCUSTOMFIELDS'=>'Lead Custom Fields',

'ACCOUNTCUSTOMFIELDS'=>'Account Custom Fields',

'CONTACTCUSTOMFIELDS'=>'Contact Custom Fields',

'OPPORTUNITYCUSTOMFIELDS'=>'Potential Custom Fields',

'HELPDESKCUSTOMFIELDS'=>'Helpdesk Custom Fields',

'PRODUCTCUSTOMFIELDS'=>'Product Custom Fields',

'VENDORCUSTOMFIELDS'=>'Vendor Custom Fields',

'PRICEBOOKCUSTOMFIELDS'=>'PriceBook Custom Fields',

'POCUSTOMFIELDS'=>'Purchase Order Custom Fields',
'SOCUSTOMFIELDS'=>'Sales Order Custom Fields',
'QUOTESCUSTOMFIELDS'=>'Quotes Custom Fields',
'INVOICECUSTOMFIELDS'=>'Invoice Custom Fields',

'EDITLEADPICKLISTVALUES'=>'Edit Lead Picklist ',

'EDITACCOUNTPICKLISTVALUES'=>'Edit Account Picklist ',

'EDITCONTACTPICKLISTVALUES'=>'Edit Contact Picklist ',

'EDITOPPORTUNITYPICKLISTVALUES'=>'Edit Potential Picklist ',

'EDITHELPDESKPICKLISTVALUES'=>'Edit HelpDesk Picklist ',

'EDITPRODUCTPICKLISTVALUES'=>'Edit Product Picklist ',

'EDITEVENTPICKLISTVALUES'=>'Edit Event Picklist ',

'EDITTASKPICKLISTVALUES'=>'Edit Task Picklist ',

'EDITRSSPICKLISTVALUES'=>'Edit Rss Picklist',
'EDITVENDORPICKLISTVALUES'=>'Edit Vendor Picklist',
'EDITPBPICKLISTVALUES'=>'Edit PriceBook Picklist',
'EDITPOPICKLISTVALUES'=>'Edit Purchase Order Picklist',
'EDITSOPICKLISTVALUES'=>'Edit Sales Order Picklist',
'EDITQUOTEPICKLISTVALUES'=>'Edit Quote Picklist',
'EDITINVOICEPICKLISTVALUES'=>'Edit Invoice Picklist',


// Added for Release vtigerCRM 3.2 PATCH 1.0

//Settings/index.php


'LBL_PICKLIST_FIELD_SETTINGS'=>'Picklist Field Settings:',



//SETTINGS/CustomFieldList.php,ComboFieldList.php,CreateCustomField.php

'Leads'=>'Lead',

'Accounts'=>'Account',

'Contacts'=>'Contact',

'Potentials'=>'Potential',

'HelpDesk'=>'HelpDesk',

'Products'=>'Product',

'Events'=>'Event',

'Activities'=>'Task',





'CustomFields'=>' Custom Fields',

'NewCustomField'=>'New Custom Field',

'NewCustomFieldAltC'=>'New Custom Field [Alt+c]:',

'FieldName'=>'Field Name',

'FieldType'=>'Field Type',

'FieldLabel'=>'Field Label',

'Delete'=>'Del',

'NEW'=>'New',

'CUSTOMFIELD'=>'Custom Field',

'LBL_CUSTOM_FIELDS'=>'Custom Fields',

'LBL_ADD_FIELD'=>'Create Custom Field',

'LBL_CUSTM_MSG'=>'allows you to ....',

'PicklistFields'=>' Picklist Fields',


'Edit'=>'Edit',

'LBL_EDIT_FIELD_TYPE'=>'Edit Field Type',

//Settings/CustomField.html

'LBL_PROVIDE_FIELD_INFORMATION'=>'Provide Field Information: ',

'LBL_SELECT_FIELD_TYPE'=>'Select Field Type: ', 

'LBL_PROVIDE_FIELD_DETAILS'=>'Provide Field Details: ',

'LBL_LABEL'=>'Label: ',

'LBL_LENGTH'=>'Length: ',

'LBL_DECIMAL_PLACES'=>'Decimal Places: ',

'LBL_PICK_LIST_VALUES'=>'Pick list Values: ',



//Settings/EditComboField.php

'EditPickListValues'=>'Picklist Edit ',



//Settings/EditField.html

'LBL_FIELD_INFORMATION'=>'Field Information:',

'Values'=>'Values',

'EnterListOfValues'=>'Please enter the list of values below. Each value should be in its own line.',



//Settings/fieldtypes.php

'Text'=>'Text',

'Number'=>'Number',

'Percent'=>'Percent',

'Currency'=>'Currency',

'Date'=>'Date',

'Email'=>'Email',

'Phone'=>'Phone',

'PickList'=>'Pick List',

'LBL_MULTISELECT_COMBO'=>'Multi-Select Combo Box',

'Skype'=>'Skype',



//added for patch2

'USERGROUPLIST'=>'Groups',

'EMAILTEMPLATES'=>'E-mail Templates',

'WORDINTEGRATION'=>'Mail Merge Templates',

'LBL_MAIL_MERGE'=>'Mail Merge',

'NOTIFICATIONSCHEDULERS'=>'Notification Schedulers',
//currency status
'LBL_ACTIVE'=>'Active',

'LBL_INACTIVE'=>'Inactive',

'LBL_NOTIFICATION'=>'Notification',
'LBL_DESCRIPTION'=>'Description',
'LBL_TOOL'=>'Tool',


//Added fields for Title Informations -- after 4 Beta

'LBL_EMAIL_CONFIG'=>'Outgoing Mail Server Configuration',

'LBL_WORD_INTEGRATION'=>'Word Integration:',

'LBL_GROUP_SETTINGS'=>'Group Settings:',

'LBL_TEMPLATE_SETTINGS'=>'Template Settings:',

'LBL_NOTIFICATION_SETTINGS'=>'Notification Settings:',

'LBL_EMAIL_SETTINGS'=>'Email Settings:',

'LBL_SECURITY_SETTINGS'=>'Security Settings:',



//Added fields after RC1 - Release

'LBL_MAIL_SERVER_INFO'=>'Outgoing Mail Server Information',

'LBL_OUTGOING_MAIL_SERVER'=>'Server Name',

'LBL_OUTGOING_MAIL_SERVER_LOGIN_USER_NAME'=>'Outgoing Mail Server Login User Name',

'LBL_OUTGOING_MAIL_SERVER_PASSWORD'=>'Outgoing Mail Server Password',

'LBL_MAIL_SERVER_SMTP'=>'Mail Server Settings (SMTP)',

'LBL_BACKUP_SERVER_CONFIG'=>'Backup Server Configuration',

'LBL_SERVER_ADDRESS'=>'Server Address',

'LBL_FTP_SERVER_NAME'=>'FTP Server Name',

'LBL_FTP_USER_NAME'=>'FTP User Name',

'LBL_FTP_PASSWORD'=>'FTP Password',

'LBL_FTP'=>'FTP',

'LBL_SYSTEM_CONFIG'=>'System Configuration',
'LBL_SYSTEM_INFO'=>'System Details',
'LBL_PROXY_SETTINGS'=>'Proxy Server',
'LBL_AUDIT_TRAIL'=>'Audit Trails',
'LBL_ENABLE_AUDIT_TRAIL'=>'Enable Audit Trail',
'LBL_USER_AUDIT'=>'Select User',
'LBL_VIEW_AUDIT_TRAIL'=>'View Audit Trail',
'LBL_AUDIT_TRAIL_DESC'=>'Display Audit Trail of Users who access CRM',
'LBL_NO_DATA'=>'No Data',

'LBL_CURRENCY_CONFIGURATION'=>'- Currency Information',

'LBL_CURRENCY_CONFIG'=>'Currency Configuration',

'LBL_CURRENCY_INFO'=>'Currency Information',

'LBL_CURRENCY_TITLE'=>'Currency',

'LBL_CURRENCY_SETTINGS'=>'Currencies',


'LBL_USERNAME'=>'User Name',
'LBL_PASWRD'=>'Password',
'LBL_REQUIRES_AUTHENT'=>'Requires Authentication?',
'LBL_FROM_EMAIL_FIELD'=>'From Email',

//Fields for Settings

'LBL_USER_MANAGEMENT'=>'Users & Access Management',

'LBL_USERS'=>'Users',

'LBL_USERS_LIST'=>'Users List',
'LBL_GROUP_LIST'=>'Groups List',

'LBL_CREATE_AND_MANAGE_USERS'=>'- Create and Manage Users (e.g., admin)',


'LBL_CREATE_AND_MANAGE_USER_ROLES'=>'- Create and Manage user roles (e.g., Administrator, Standard User, etc.)',

'LBL_PROFILES'=>'Profiles',

'LBL_PROFILES_LIST'=>'Profiles List',

'LBL_CREATE_AND_MANAGE_USER_PROFILES'=>'- Create and Manage user profiles (e.g., CEO, Sales Manager, etc.)',

'LBL_CREATE_AND_MANAGE_USER_GROUPS'=>'- Create and Manage user groups',

'LBL_SHARING_ACCESS'=>'Sharing Access',

'LBL_FIELDS_ACCESS'=>'Fields Access',

'LBL_DEFAULT_ORGANIZATION_FIELDS'=>'Default Organization Fields Access',

'LBL_SETTING_DEFAULT_ORGANIZATION_FIELDS'=>' - Setting Default Field Access within the Organization',

'LBL_SETTING_DEFAULT_SHARING_ACCESS'=>'- Setting Default Sharing Access within the Organization',

'LBL_FIELD_ACCESSIBILITY'=>'Field Accessibility',

'LBL_SETTING_FIELD_ACCESSIBILITY'=>' - Setting Field Accessibility for each profiles',
//<<<<<<<<for edit ordering blocks>>>>>>
'LBL_FIELD_ORDERING_DESC'=>' - Edit Field Order',

'LBL_FIELD_ORDERING'=>'Edit Field Blocks',
//<<<<<<<<<<end>>>>>>>>>>>>>
'LBL_LEAD_FIELD_ACCESS'=>'Lead Field Access',

'LBL_ACCOUNT_FIELD_ACCESS'=>'Account Field Access',

'LBL_CONTACT_FIELD_ACCESS'=>'Contact Field Access',

'LBL_OPPORTUNITY_FIELD_ACCESS'=>'Potential Field Access',

'LBL_HELPDESK_FIELD_ACCESS'=>'HelpDesk Field Access',

'LBL_PRODUCT_FIELD_ACCESS'=>'Product Field Access',

'LBL_NOTE_FIELD_ACCESS'=>'Document Field Access',

'LBL_EMAIL_FIELD_ACCESS'=>'Email Field Access',

'LBL_TASK_FIELD_ACCESS'=>'Task Field Access',

'LBL_EVENT_FIELD_ACCESS'=>'Event Field Access',

'LBL_DELETE_DEMO_DATA'=>'Delete Demo Data',

'LBL_DELETE_DEMO_DATA_INFO'=>'- Delete the Demo Data which is created at the time of installation',



'LBL_STUDIO'=>'Studio',

'LBL_CUSTOM_FIELD_SETTINGS'=>'Custom Field Settings',

'LBL_CREATE_AND_MANAGE_USER_DEFINED_FIELDS'=>'Manage your company-wide custom fields.',

'LBL_SELECT_MODULE'=>'Select Module',

'LBL_SELECT_CF_TEXT'=>'<b>Select Module:</b>',



'LBL_PICKLIST_SETTINGS'=>'Picklist Settings',

'LBL_EDIT_PICKLIST_VALUES'=>' - Edit values of Picklist fields',

'LBL_EDIT'=>'Editing',

'LBL_COMMUNICATION_TEMPLATES'=>'Communication Templates',

'LBL_CREATE_EMAIL_TEMPLATES'=>'New Email Template',

'LBL_UPLOAD_MSWORD_TEMPLATES'=>' - Upload MS Word Templates for Mail Merge',

'LBL_SCHEDULE_EMAIL_NOTIFICATION'=>' - Schedule Email Notifications',

'LBL_EXPAND_CLOSE_MENU'=>'Expand/Close Menu',

'LBL_CONFIGURATION'=>'Configuration',

'LBL_CONFIGURE_MAIL_SERVER'=>' - Configure Outgoing Mail Server',

'LBL_BACKUP_SERVER_CONFIGURATION'=>'Backup Server Configuration',

'LBL_BACKUP_SERVER_INFO'=>'Backup Server Information',

'LBL_BACKUP_SERVER_SETTINGS'=>'Backup Server',

'LBL_CONFIGURE_BACKUP_SERVER'=>' - Configure Backup Server',

'LBL_SYSTEM_CONFIGURATION'=>' - System Configuration',

'LBL_PROXY_SERVER_CONFIGURATION'=>'Proxy Server Configuration',

'LBL_PROXY_SERVER_INFO'=>'Proxy Server Information',

'LBL_PROXY_SERVER_SETTINGS'=>'Proxy Server',

'LBL_CONFIGURE_PROXY_SERVER'=>' - Configure Proxy Server',

'LBL_PROXY_PORT'=>'Port Number',



//Field Types for custom fields

'LBL_URL'=>'URL',

'LBL_CHECK_BOX'=>'Checkbox',



//PickList Settings

'LBL_STANDARD_FIELDS'=>'Standard Fields',

'LBL_LEAD_SOURCE'=>'Lead Source',

'LBL_SALUTATION'=>'Salutation',

'LBL_LEAD_STATUS'=>'Lead Status',

'LBL_INDUSTRY'=>'Industry',

'LBL_RATING'=>'Rating',

'LBL_ACCOUNT_TYPE'=>'Account Type',

'LBL_BUSINESS_TYPE'=>'Business Type',

'LBL_CURRENCY_TYPE'=>'Currency Type',

'LBL_SALES_STAGE'=>'Sales Stage',

'LBL_PRIORITY'=>'Priority',

'LBL_STATUS'=>'Status',

'LBL_CATEGORY'=>'Ticket Category',

'LBL_MANUFACTURER'=>'Manufacturer',

'LBL_PRODUCT_CATEGORY'=>'Product Category',

'LBL_RSS_CATEGORY'=>'Rss Category',

//Added for Web based Email client integration (post 4.0.1 release)

'LBL_ADD_MAIL_ACCOUNT'=>'Add Mail Account',
'LBL_NEW_MAIL_ACCOUNT_TITLE'=>'New Mail Account [Alt+M]',
'LBL_NEW_MAIL_ACCOUNT_KEY'=>'M',
'LBL_NEW_MAIL_ACCOUNT_LABEL'=>'New Mail Account',
'LBL_GENERAL_INFO'=>'General Information',
'LBL_DISPLAY_NAME'=>'Display Name',
'LBL_MAIL_PROTOCOL'=>'Mail Protocol',
'LBL_LIST_PASSWORD'=>'Password',
'LBL_MAIL_SERVER_NAME'=>'Mail Server Name or IP',
'LBL_MAIL_SERVER_SETTINGS'=>'Outgoing Server',
'LBL_INCOME_SERVER_SETTINGS'=>'Incoming Server',
'LBL_TEST_SETTINGS'=>'Test my account setting immediately',
'LBL_TEST_BUTTON_TITLE'=>'Test my account now! [Alt+T]',
'LBL_TEST_BUTTON_KEY'=>'T',
'LBL_TEST_BUTTON_LABEL'=>'Test my account now!',
'LBL_DEFAULT'=>'Default',
'LBL_IMAP2'=>'IMAP2',
'LBL_IMAP4'=>'IMAP4',
'LBL_POP'=>'POP',
'LBL_IMAP'=>'IMAP',
'LBL_MAIL_DISCLAIM'=>'Items marked with <font color="red">*</font> are required<br>Items marked with <font color="red">* *</font> are not fully supported',
'LBL_SSL_OPTIONS'=>'SSL Options',
'LBL_TLS'=>'TLS',
'LBL_NO_TLS'=>'No TLS',
'LBL_CERT_VAL'=>'Certificate Validations',
'LBL_INT_MAILER'=>'Use Internal Mailer?',
'LBL_INT_MAILER_USE'=>'Yes',
'LBL_INT_MAILER_NOUSE'=>'No',
'LBL_VAL_SSL_CERT'=>'Validate SSL Cert',
'LBL_DONOT_VAL_SSL_CERT'=>'Do Not Validate SSL Cert',
'LBL_WEB_MAIL_CONFIG'=>'Web Mail Configuration',
'LBL_CONFIGURE_WEB_MAIL'=>' - Configure Web Mail',
'LBL_LIST_MAIL_ACCOUNT'=>'  List Mail Account',
'LBL_USAGEUNIT'=>'Usage Unit',
'LBL_GLACCT'=>'GL Account',
'LBL_QUOTE_STAGE'=>'Quote Stage',
'LBL_CARRIER'=>'Carrier',
'LBL_TAXCLASS'=>'Tax Class',
'LBL_MY_DETAILS'=>'My Details',
'LBL_MY_MAIL_SERVER_DET'=>'My Incoming Mail Server Details',
'LBL_EMAIL_ID'=>'Email ID',
'LBL_NAME_EXAMPLE'=>'(example : John Fenner)',
'LBL_EMAIL_EXAMPLE'=>'(example : johnfenner@xyz.com)',
'LBL_REFRESH_TIMEOUT'=>'Refresh Timeout',
'LBL_1_MIN'=>'1 minute',
'LBL_2_MIN'=>'2 minutes',
'LBL_3_MIN'=>'3 minutes',
'LBL_4_MIN'=>'4 minutes',
'LBL_5_MIN'=>'5 minutes',
'LBL_EMAILS_PER_PAGE'=>'Email per Page',

//Added for Organization Details (4.2 release)
'LBL_ORGANIZATION_NAME'=>'Company Name',
'LBL_ORGANIZATION_ADDRESS'=>'Address',
'LBL_ORGANIZATION_CITY'=>'City',
'LBL_ORGANIZATION_STATE'=>'State',
'LBL_ORGANIZATION_CODE'=>'Postal Code',
'LBL_ORGANIZATION_COUNTRY'=>'Country',
'LBL_ORGANIZATION_PHONE'=>'Phone',
'LBL_ORGANIZATION_FAX'=>'Fax',
'LBL_ORGANIZATION_WEBSITE'=>'Website',
'LBL_ORGANIZATION_DETAILS'=>'Company Information',
'LBL_SPECIFY_COMPANY_DETAILS'=>' - Specify Company Information',
'LBL_ORGANIZATION_LOGO'=>'Company Logo',
'LBL_UPLOAD'=>'Upload',
'LBL_FILENAME'=>'File Name',
'LBL_SETTINGS'=>'Settings',
'LBL_COMPANY_DETAILS'=>'Company Details',

'LBL_SEVERITY'=>'Severity',
'LBL_FAQ_CATEGORY'=>'FAQ Category',
'LBL_VENDOR_FIELD_ACCESS'=>'Vendor Field Access',
'LBL_PB_FIELD_ACCESS'=>'PriceBook Field Access',
'LBL_QUOTE_FIELD_ACCESS'=>'Quote Field Access',
'LBL_PO_FIELD_ACCESS'=>'Purchase Order Field Access',
'LBL_SO_FIELD_ACCESS'=>'Sales Order Access',
'LBL_INVOICE_FIELD_ACCESS'=>'Invoice Field Access',
'INVENTORYNOTIFICATION'=>'Inventory Notifications',
'LBL_INVENTORY_NOTIFICATIONS'=>' - Edit Inventory Email Notifications',
'INVENTORYTERMSANDCONDITIONS'=>'Inventory : Terms & Conditions',//newly added for Inventory terms and conditions
'LBL_INVENTORY_TERMSANDCONDITIONS'=>' - Edit Terms & Conditions',//newly added
'LBL_TANDC_TEXT'=>'Terms & Conditions Text',
'LBL_INVENTORY_TANDC'=>'Inventory Terms & Conditions',

'LBL_OTHER_SETTINGS'=>'Other Settings',
'LBL_SCROLL'=>'[Scroll to Top]',

'LBL_INV_NOT_DESC'=>'The following is the list of notifications that are sent to the product handler regarding the demand and the current quantity in hand during the creation of a Quote, SalesOrder and Invoice.',

'InvoiceNotification'=>'Product Stock Notification during Invoice Generation',
'InvoiceNotificationDescription'=>'When the product stock level goes below the re-order level, notification will be sent to the product handler',
'Vendor'=>'Vendor',
'PriceBook'=>'PriceBook',
'Quotes'=>'Quote',
'PurchaseOrder'=>'Purchase Order',
'SalesOrder'=>'SalesOrder',
'Invoice'=>'Invoice',

//For Custom Fields
'LBL_LEAD_MAP_CUSTOM_FIELD'=>'Mapping Lead Custom Fields',
'leadCustomFieldDescription'=>'Map each of your organizations lead custom fields to each of your custom account
,contact, or potential fields. These mappings will be used when you convert leads',
'LBL_MAPPING_INFO'=>'Mapping Information',
'LBL_ACCOUNT_FIELD'=>'Account Custom Field',
'LBL_CONTACT_FIELD'=>'Contact Custom Field',
'LBL_POTENTIAL_FIELD'=>'Potential Custom Field',
'CUSTOMFIELDMAPPING'=>'Custom Field Mapping',
'LBL_FIELD_MAPPING'=>'Field Mapping',
'LBL_LEAD_FIELD'=>'Lead Custom Field',
//After 4.2 GA
'LBL_TEXT_AREA'=>'Text Area',
//for Edit ordering the blocks
'NOTESCUSTOMFIELDS'=>'Documents Custom Fields',

//Added fields after 4.2 ptach 2
'LBL_ASSIGN_MODULE_OWNERS'=>'Assign Module Owners',
'LBL_MODULE_OWNERS'=>'Module Owners',
'LBL_ASSIGN_MODULE_OWNERS_INFO'=>' - Assign Owners for each modules',
'LBL_MODULE'=>'CRM Module',
'LBL_OWNER'=>'Assigned Owner',
'LBL_MIGRATION'=>'Migration Wizard',
'LBL_MIGRATION_INFO'=>'Migrate your existing vtiger CRM data to latest version',

//Added for 5 GA - Description of Settings UI

'LBL_USER_DESCRIPTION'=>'Manage users who can access vtiger CRM',
'LBL_ROLE_DESCRIPTION'=>'Set up hierarchy of roles and assign to the users',
'LBL_PROFILE_DESCRIPTION'=>'Manage user-specific modules access to different Roles',
'LBL_GROUP_DESCRIPTION'=>'Manage different types of teams based on roles, users, and profiles',
'LBL_SHARING_ACCESS_DESCRIPTION'=>'Manage module sharing rules & custom sharing rules',
'LBL_SHARING_FIELDS_DESCRIPTION'=>'Define global field-level access in each module',
'LBL_MODULE_OWNERS_DESCRIPTION'=>'Assign Customer Support owners to CRM module',
'LBL_ANNOUNCEMENT_DESCRIPTION'=>'Manage company wide announcements',
'LBL_CUSTOM_FIELDS_DESCRIPTION'=>'Manage different types of user-defined fields',
'LBL_PICKLIST_DESCRIPTION'=>'Customize Picklist values in each module',
'LBL_EMAIL_TEMPLATE_DESCRIPTION'=>'Manage templates for E-Mail module',
'LBL_MAIL_MERGE_DESCRIPTION'=>'Manage templates for Mail Merging',
'LBL_NOTIF_SCHED_DESCRIPTION'=>'Manage Notifications that will alert in case of important actions',
'LBL_INV_NOTIF_DESCRIPTION'=>'Change Settings of Inventory related Notifications',
'LBL_INV_TANDC_DESCRIPTION'=>'Specify Terms and Conditions for quotes, orders, and invoices',
'LBL_COMPANY_DESCRIPTION'=>'Specify business address of company',
'LBL_MAIL_SERVER_DESCRIPTION'=>'Configure Outgoing Mail Server details',
'LBL_BACKUP_SERVER_DESCRIPTION'=>'Specify database backup server details',
'LBL_CURRENCY_DESCRIPTION'=>'Manage international currencies and exchange rates',
'LBL_TAX_DESCRIPTION'=>'Manage taxes and the corresponding tax rates',
'LBL_SYSTEM_DESCRIPTION'=>'View vtiger CRM Server details',
'LBL_PROXY_DESCRIPTION'=>'Configure proxies to access RSS feeds through Internet',
'LBL_AUDIT_DESCRIPTION'=>'Display data opertions performed by users',
'LBL_TAX_DESC'=>'Manage different types of tax rates for taxes, such as Sales Tax, VAT etc.,',
'LBL_COMPANY_DESC'=>'Specify business address of your company',
'LBL_SELECT_LOGO'=>'Select new logo:',
'LBL_INVEN_TANDC_DESC'=>'Specify text for the Terms & Conditions section of Quotes, Orders, and Invoices modules',
'LBL_MAIL_SERVER_DESC'=>'Configure your Outgoing Mail Server details',
'LBL_BACKUP_SERVER_DESC'=>'Manage your Backup Server',
'LBL_MODULES_AND_OWNERS'=>'Modules & Owners',
'LBL_GROUP_DESC'=>'Manage different types of user groups within your organization',
'LBL_MAIL_MERGE_DESC'=>'Manage Mail Merge templates used in CRM modules',


//Added fields after 5.0 Alpha
'LBL_REQUIRE_SMTP_AUTHENTICATION'=>'Require SMTP Authentication?',
'LBL_ANNOUNCEMENT'=>'Announcements',
'LBL_SETTING_ANNOUNCEMENT'=>'Announcement',
'LBL_ANNOUNCE_TEXT'=>'Announcement Text',
'LBL_UPDATE_BUTTON'=>'Update',
'LBL_ANNOUNCEMENT_INFO'=>'Type the announcement text below, and click the Update button.',
'LBL_ANNOUNCEMENT_DESC'=>'Change the text that appears in the announcement display on top of each page',
'LBL_EMAIL_CONTENTS'=>'Email Contents',
'LBL_SUBJECT'=>'Subject',
'LBL_MESSAGE'=>'Message',
'LBL_PICKLIST_EDITOR'=>'Picklist Editor',
'LBL_PICKLIST_AVAIL'=>'Picklists Available in',
'LBL_PICKLIST_AVAILINFO1'=>'The picklists available in',
'LBL_PICKLIST_AVAILINFO2'=>'are shown below. Click Edit to modify the contents of the list.',
'LBL_EDIT_PICKLIST'=>'Edit Pick List',
'LBL_PICKLIST_SAVEINFO'=>'Type the entries one - by - one below and click the Save button to save the list.',
'LBL_SELECT_CRM_MODULE'=>'Select CRM Module',
'LBL_TAX_SETTINGS'=>'Tax Calculations',
'LBL_INVENTORY_TAX_CONFIG'=>'Inventory Tax Configuration',
'LBL_CUSTOM_MAPP_INFO'=>'Only in Leads module you can map the fields with Accounts, Contacts, and Potentials.',
'LBL_MAPPING_OTHER_MODULES'=>'Mapping with other Modules',
'LBL_CUSTOM_FILED_IN'=>'Custom Fields in ',
'LBL_ROLE_HIERARCHY_TREE'=>'Roles & Hierarchy Tree',
'LBL_EDIT_FIELD_MAPPING'=>'Editing Field Mapping',
'LBL_LOGIN_HISTORY_DETAILS'=>'User Login History',
'LBL_LOGIN_HISTORY_DESCRIPTION'=>'Display login history of users',
'LBL_NON_EDITABLE_PICKLIST_ENTRIES'=>'Non Editable Picklist Entries',

//Added for Tax settings
'LBL_PRODUCT_TAX_SETTINGS'=>'Product & Service Taxes',
'LBL_SHIPPING_HANDLING_TAX_SETTINGS'=>'Shipping & Handling Taxes',
'LBL_PROXY_SERVER_DESC'=>'Configure proxies to access RSS feeds through Internet',

'LBL_NEW_CURRENCTY'=>'New Currency',
'LBL_BASE_CURRENCY'=>'Base Currency - ',
'LBL_DELETE_CURRENCY'=>'Delete Currency',

//Added for singlepane view in modules 

'LBL_DEFAULT_DETAIL_VIEW'=>'Default Detail View',
'LBL_DEFAULT_MODULE_VIEW'=>'Default Module View',
'LBL_DEFAULT_MODULE_VIEW_DESC'=>'Set Default Detail View for All Modules',
'LBL_ENABLE_SINGLEPANE_VIEW'=>'Enable Singlepane View',

'LBL_CLEAR_DATA'=>'Clear Data',
'LBL_ENABLE'=>'Enable',
'LBL_FAQ_FIELD_ACCESS'=>'Faq Field Access',
'LBL_ADD_TAX_BUTTON'=>'Add Tax',
'LBL_NO_TAXES_AVAILABLE'=>'No taxes available',
'LBL_PLEASE'=>'Please',
//Added while moving role file from User to Setting Module
'LBL_ROLES'=>'Roles',
'LBL_CREATE_NEW_ROLE'=>'Create New Role',
'LBL_PROPERTIES'=>'Properties of',
'LBL_NEW_ROLE'=>'New Role',
'LBL_ROLE_NAME'=>'Role Name',
'LBL_REPORTS_TO'=>'Reports to',
'LBL_PROFILE_M'=>'Profile',
'LBL_PROFILES_AVLBL'=>'Profiles Available',
'LBL_ASSIGN_PROFILES'=>'Assigned Profiles',
'LBL_MEMBER'=>'Members',
'LBL_DELETE_ROLE'=>'Delete Role',
'LBL_ROLE_TO_BE_DELETED'=>'Role to be Deleted',
'LBL_TRANSFER_USER_ROLE'=>'Transfer Users to Role',
'LBL_ASSOCIATED_PROFILES'=>'Associated Profiles :',
'LBL_ASSOCIATED_USERS'=>'Associated Users :',
//Added while moving email templates from Users to Settings
'LBL_EMAIL_TEMPLATES'=>'Email Templates',
'LBL_EMAIL_TEMPLATE_DESC'=>'Manage email templates used for Campaigns and Mass mailing',
'LBL_LIST_SELECT'=>'Select',
'LBL_EMAIL_TEMPLATE'=>'Email Template',
'LBL_TEMPLATE_TOOLS'=>'Tools',
'LBL_NEW_TEMPLATE' =>'New Template',
'LBL_FOLDER'=>'Folder',
'LBL_NAME'=>'Name',
'LBL_PERSONAL'=>'Personal',
'LBL_PUBLIC'=>'Public',
'LBL_ACCOUNT_FIELDS'=>'Account Fields',
'LBL_CONTACT_FIELDS'=>'Contact Fields',
'LBL_LEAD_FIELDS'=>'Lead Fields',
'LBL_USER_FIELDS'=>'User Fields',
'LNK_SAMPLE_EMAIL'=>'View Sample Email',
//Added while moving Mail Merge templates from Users to Settings
'LBL_TEMPLATE_FILE'=>'Template File',
'LBL_MODULENAMES'=>'Module',
'LBL_DOWNLOAD'=>'Download',
'LBL_ADD_TEMPLATE'=>'Add Template',
'LBL_WORD_TEMPLATES'=>'Mail Merge Templates',
//Added while moving Notification Schedulers from Users to Settings
'LBL_TASK_NOTIFICATION'=>'Delayed Task Notification',
'LBL_BIG_DEAL'=>'Big Deal Notification',
'LBL_PENDING_TICKETS'=>'Pending Tickets Notification',
'LBL_MANY_TICKETS'=>'Too many tickets  Notification',
'LBL_START_NOTIFICATION'=>'Support Start Notification',
'LBL_ACTIVITY_NOTIFICATION'=>'Event Reminder Notification',

'LBL_TASK_NOTIFICATION_DESCRITPION'=>'Notify when a task is delayed beyond 24 hrs',
'LBL_BIG_DEAL_DESCRIPTION'=>'Notify on completion of big deal',
'LBL_TICKETS_DESCRIPTION'=>'Notify for getting attention to status of tickets which are pending',
'LBL_MANY_TICKETS_DESCRIPTION'=>'Notify when a particular entity is allocated too many tickets, might reflect Service Level commitments',
'LBL_START_DESCRIPTION'=>'Notifiy stating the start of support/service',
'LBL_ACTIVITY_REMINDER_DESCRIPTION'=>'Notify before an event to occur based on the reminder set',
//Added while moving Inventory Notifications from Users to Settings
'QuoteNotificationDescription'=>'During quote generation if the product stock in warehouse is lesser than the  quantity mentioned in quote then this notification will be sent to the product handler',
'SalesOrderNotificationDescription'=>'During sales order generation if the product stock in warehouse is lesser than the quantity mentioned in sales order then this notification will be sent to the product handler',
'Tools'=>'Tools',
'QuoteNotification'=>'Product Stock Notification during Quote Generation',
'SalesOrderNotification'=>'Product Stock Notification during Sales Order Generation',
'LBL_NOTE_DO_NOT_REMOVE_INFO'=>'Note: Donot remove or alter the values within {  }',

//Added while moving Profile file from User to Setting Module
'LBL_TOTAL'=>'Total :',
'LBL_NEW_PROFILE'=>'New Profile',
'LBL_LIST_NO'=>'#',
'LBL_NEW_PROFILE_NAME'=>'Profile Name',
'LBL_LIST_TOOLS'=>'Tools',
'LBL_PROFILE_MESG'=>'Viewing access privileges for',
'LBL_PROFILE_PRIVILEGES'=>'Profile Privileges',
'LBL_DEFINE_PRIV_FOR'=>' Define Privileges for ',
'LBL_USE_OPTION_TO_SET_PRIV'=>'Use the options below to set privileges',
'LBL_SUPER_USER_PRIV'=>'Global Privileges',
'LBL_SET_PRIV_FOR_EACH_MODULE'=>'Set Privileges for each Module ',
'LBL_FIELDS_AND_TOOLS_SETTINGS'=>'Fields & Tools Settings',
'LBL_VIEW_ALL'=>'View all',
'LBL_EDIT_ALL'=>'Edit all',
'LBL_ALLOW'=>'Allows',
'LBL_MESG_VIEW'=>'to view all information / modules of vtiger CRM',
'LBL_MESG_EDIT'=>'to edit all information / modules of vtiger CRM',
'LBL_TAB_MESG_OPTION'=>'modules to be shown',
'LBL_CREATE_EDIT'=>'Create/Edit',
'LBL_VIEW'=>'View',
'LBL_MANDATORY_MSG'=>'Mandatory Fields',
'LBL_DISABLE_FIELD_MSG'=>'Fields Disabled from Global Field Access Settings',
'LBL_DELETE'=>'Delete',

'LBL_STEP_2_2'=>'Step 2 of 2',
'LBL_FINISH_BUTTON'=>'Finish',

//Added while moving Groups file from User to Setting Module
'LBL_NEW_GROUP'=>'New Group',
'LBL_GROUPS'=>'Groups',
'LBL_GROUP_NAME'=>'Group Name',
'LBL_ROLES_SUBORDINATES'=>'Roles and Subordinates',
'LBL_MEMBER_AVLBL'=>'Available Entities & Members',
'LBL_MEMBER_SELECTED'=>'Selected Members',
'LBL_ENTITY'=>'Entity',
'LBL_OF'=>'of',
'LBL_CREATE_NEW_GROUP'=>'Create New Group',
'LBL_ADD_GROUP_BUTTON'=>'Add Group',
'LBL_GROUP_MESG1'=>'Groups are a flexible way to assign access rights, when complex access rights has to be defined. You can combine multiple entities like Roles, Users, profiles etc into a single group.',
'LBL_GROUP_MESG2'=>'To add, select the Entity members from left and click the ">>" button.',
'LBL_GROUP_MESG3'=>'To remove, select the group members from the right and click the "<<" button.',

//Sharing Privileges
'LBL_GLOBAL_ACCESS_PRIVILEGES'=>'Organization-level Sharing Rules',
'LBL_RECALCULATE_BUTTON'=>'Recalculate',
'LBL_CHANGE'=>'Change',
'LBL_PRIVILEGES'=>'Privileges',
'LBL_CUSTOM_ACCESS_PRIVILEGES'=>'Custom Sharing Rules',
'LBL_ADD_PRIVILEGES_BUTTON'=>'Add Privileges',
'LBL_RULE_NO'=>'Rule No.',
'LBL_CAN_BE_ACCESSED'=>'can be accessed by',
'LBL_CUSTOM_ACCESS_MESG'=>'No Custom Access Rules defined .',
'LNK_CLICK_HERE'=>'Click here',
'LBL_CREATE_RULE_MESG'=>'to create a new Rule',
'LBL_RECALC_MSG'=>'Are you sure, you wish to Recalculate Sharing Access?',
'LBL_YES'=>'Yes',
'LBL_NO'=>'No',
'LBL_IN_PERMISSION'=>'in the permission',
'LBL_RELATED_MODULE_RIGHTS'=>'Related Module Rights',
'LBL_USR_CAN_ACCESS'=>'Users can ',
'LBL_USR_OTHERS'=>' other users ',
'LBL_USR_CANNOT_ACCESS'=>'Users cannot access other users ',
 
'LBL_ORG_SHARING_PRIVILEGES'=>'Organisation Sharing  Privileges',
'LBL_EDIT_PERMISSIONS'=>'Edit Permissions',
'LBL_SAVE_PERMISSIONS'=>'Save Permissions',
'LBL_READ_ONLY'=>'Public: Read Only',
'LBL_EDIT_CREATE_ONLY'=>'Public: Read, Create/Edit',
'LBL_READ_CREATE_EDIT_DEL'=>'Public: Read, Create/Edit, Delete',
'LBL_PRIVATE'=>'Private',
 
'Public: Read Only'=>'Public: Read Only',

'Public: Read, Create/Edit'=>'Public: Read, Create/Edit',

'Public: Read, Create/Edit, Delete'=>'Public: Read, Create/Edit, Delete',

'Private'=>'Private',
'Hide Details'=>'Hide Details',
'Hide Details and Add Events'=>'Hide Details and Add Events',
'Show Details'=>'Show Details',
'Show Details and Add Events'=>'Show Details and Add Events',

//Added for User Login History While moving from User to Settings
'LBL_LOGIN_HISTORY'=>'Login History',
//Sharing Access module moved to Setting
'Read/Write'=>'Read/Write',
'Read Only '=>'Read Only ',
'LBL_GROUP'=>'Group',
'LBL_ACCESS_RIGHTS_FOR_MODULES'=>'Access rights for relative modules',
'LBL_ADD_RULE'=>'Add Rule',
'LBL_ADD_CUSTOM_RULE'=>'Add Custom Privilege Rule',
'LBL_RULE_CONSTRUCTION'=>'Rule Construction Display',
'LBL_STEP'=>'Step',
'LBL_SELECT_ENTITY'=>'Select an entity below',
'LBL_CAN_BE_ACCESSED_BY'=>'Can be accessed by',
'LBL_PERMISSIONS'=>'Permissions',
'LBL_DOC_MSWORD'=>'File has to be a Document of type doc/msword',
'LBL_NODOC'=>'No doc File in this directory.Please try again!',

//Added for error messages on Company Info.
'LOGO_ERROR'=>'Logo has to be an Image of type jpeg/png',
'Error_Message'=>'Error Message',
'Invalid_file'=>'Invalid file OR',
'File_has_no_data'=>'File has no data',
'Sorry'=>'Sorry',
'uploaded_file_exceeds_maximum_limit'=>'the uploaded file exceeds the maximum vtiger_filesize limit',
'try_file_smaller'=>'Please try a file smaller than 800000 bytes',
'Problems_in_upload'=>'Problems in file upload',
'Please_try_again'=>'Please try again!',
//5.0.3 fixes
'LBL_TESTMAILSTATUS'=>'Test Mail Status : ',
'LBL_CHECK_ASSIGNEDTO_MAILID'=>'Please check the assigned-to emailid',
'LBL_MAILSENDERROR'=>'Mail could not be sent to the admin user. Please check the admin emailid/Server settings',
'LBL_RECORD_NOEXIST'=>'Record not present',
'LBL_ENTER_PROFILE'=>'Enter Profile Name',
'LBL_ENABLE'=>'Enable',
'LBL_DISABLE'=>'Disable',
'LBL_PROXY'=>'proxy',
'LBL_FIELDS_TO_BE_SHOWN'=>'Fields to be shown',
//Added for alerts
'SPECIFY_FILE_TO_MERGE' => 'Please Specify a File to Merge',
'FILESIZE_EXCEEDS_INFO_CONFIG_INC' => 'Sorry, the uploaded file exceeds the maximum file size limit in config.inc.php. Please try a smaller file',
'FILESIZE_EXCEEDS_INFO_PHP_INI' => 'Sorry, the uploaded file exceeds the maximum file size limit in php.ini. Please try a smaller file',
'PROBLEMS_IN_FILEUPLOAD' => 'Problems in file upload. Please try again!',

//Added fields for Invoice Number labels
'LBL_CUSTOMIZE_INVOICE_NUMBER'=>'Customize Invoice Number',
'LBL_CUSTOMIZE_INVOICE_NUMBER_DESCRIPTION'=>'Invoice Number Customization',
'LBL_CUSTOM_INVOICE_NUMBER_VIEW'=>'Invoice Number Customization',
'LBL_CUSTOMINVOICE_STRING'=>'Custom Invoice String',
'LBL_CUSTOMINVOICE_NUMBER'=>'Custom Invoice Number',
'LBL_INVOICE_NUMBER_PREVIEW'=>'Preview',
'LBL_INVOICE_NUMBER_BUTTON'=>'Update Invoice Number',
'LBL_PROXY_AUTHENTICATION_REQUIRED'=>'Proxy Authentication Required',
'LBL_ENABLE_FTP' => 'You must have FTP support enabled in php',

//Added for Role Labels
'LBL_ADD_ROLE'=>'Add Role',
'LBL_EDIT_ROLE'=>'Edit Role',
'LBL_MOVE_ROLE'=>'Move Role',
'LBL_BACKUP_DESC'=>' The CRM system allows you to make a backup of the database to your FTP server. The CRM will take backup of all data whenever an admin user logs out. Make sure you have enough disk space available on your FTP server. The created backup file will be in the following format: "backup_date_time.sql".',

// Added/Updated for vtiger CRM 5.0.4
'LBL_SUPPORT_NOTICIATION'=>'Support End Notification before a week',
'LBL_SUPPORT_NOTICIATION_MONTH'=>'Support End Notification before a month' ,
'LBL_SUPPORT_DESCRIPTION'=>'Notify before one week when support is about to end',
'LBL_SUPPORT_DESCRIPTION_MONTH'=>'Notify before one month when support is about to end',
'LBL_SELECT_ROLE'=>'Select Role',
'LBL_TEMPLATE'=>'Template',
'LBL_SELECT_EMAIL_TEMPLATE_FOR'=>'Select the Email Template for',

'ERR_CUSTOM_FIELD_WITH_NAME'=>'Custom Field with the Name ',
'ERR_ALREADY_EXISTS'=>' already exists.',
'ERR_SPECIFY_DIFFERENT_LABEL'=>'Please specify a different Label',
'LBL_TOOLS_TO_BE_SHOWN'=>'Tools to be shown',
'LBL_PICKLIST_GLOBAL_CHANGE'=>'Global Change',
'LBL_PICKLIST_TRANSFER'=>'Transfering the values Of ',
'LBL_REPLACE_VALUE_WITH'=>'Replace value with ',
'LBL_EDIT_CUSTOM_RULE'=>'Edit Custom Privilege Rule',

/*for global add/delete in picklist*/
'DELETE_PICKLIST_VALUES'=>'Delete PickList Values',
'EDIT_PICKLIST_VALUE'=>'Edit PickList Value',
'ADD_PICKLIST_VALUES'=>'Add PickList Values',
'LBL_PICKLIST_ADDINFO'=>'Type the new entries one-by-one below',
'LBL_SELECT_ROLES'=> 'Select the Roles to which entries have to be added',
'LBL_EXISTING_PICKLIST_VALUES'=>'Existing Picklist Values',
'LBL_SELECT_PICKLIST'=>'Select picklist',

// Added after 5.0.4 GA

'LBL_GENERAL_FIELDS'=>'General Fields',

'LBL_CANCEL_BUTTON'=>'Cancel',

//Added fields for Inventory Number labels
'LBL_CUSTOMIZE_INVENTORY_NUMBER'=>'Customize Inventory Sequence',
'LBL_CUSTOMIZE_INVENTORY_NUMBER_DESCRIPTION'=>'Inventory Sequence Customization',
'LBL_CUSTOM_QUOTE_NUMBER_VIEW'=>'Quote Number Customization',
'LBL_CUSTOMQUOTE_STRING'=>'Custom Quote String',
'LBL_CUSTOMQUOTE_NUMBER'=>'Custom Quote Number',
'LBL_QUOTE_NUMBER_PREVIEW'=>'Preview',
'LBL_QUOTE_NUMBER_BUTTON'=>'Update Quote Number',
'LBL_CUSTOM_SO_NUMBER_VIEW'=>'SalesOrder Number Customization',
'LBL_CUSTOMSO_STRING'=>'Custom SalesOrder String',
'LBL_CUSTOMSO_NUMBER'=>'Custom SalesOrder Number',
'LBL_SO_NUMBER_PREVIEW'=>'Preview',
'LBL_SO_NUMBER_BUTTON'=>'Update SalesOrder Number',
'LBL_CUSTOM_PO_NUMBER_VIEW'=>'PurchaseOrder Number Customization',
'LBL_CUSTOMPO_STRING'=>'Custom PurchaseOrder String',
'LBL_CUSTOMPO_NUMBER'=>'Custom PurchaseOrder Number',
'LBL_PO_NUMBER_PREVIEW'=>'Preview',
'LBL_PO_NUMBER_BUTTON'=>'Update PurchaseOrder Number',

// Added after 5.0.4 GA

// Added for Multi-Currency Support
'LBL_TRANSFER_CURRENCY'=>'Transfer Currency',
'LBL_CURRENT_CURRENCY'=>'Current Currency',

//Added for new backup labels
'LBL_LOCAL'=>'Local',
'LBL_BACKUP'=>'Backup',
'LBL_BACKUP_LOCATION'=>'Backup Location',

'LBL_LAYOUT_EDITOR'=>'Layout Editor',
'LBL_LAYOUT_EDITOR_DESCRIPTION'=>'Designing and Modifying the layout in each of the modules',
'LBL_Show'=>'Show',
'LBL_Hide'=>'Hide',

// vtlib customization: Language Stings
'VTLIB_LBL_MODULE_MANAGER'=>'Module Manager',
'VTLIB_LBL_MODULE_MANAGER_DESCRIPTION'=>'Manage module behavior inside vtiger CRM',
'VTLIB_LBL_MODULE_MANAGER_CUSTOMMOD'=>'Custom Modules',
'VTLIB_LBL_MODULE_MANAGER_STANDARDMOD'=>'Standard Modules',
'VTLIB_LBL_MODULE_MANAGER_NOMODULES'=>'No custom modules found! Create one or Import New ...',

// vtmailscanner START
'LBL_MAIL_SCANNER'=>'Mail Converter',
'LBL_MAIL_SCANNER_DESCRIPTION'=>'Configure mailbox for scanning',
'LBL_SCAN_NOW'=>'Scan Now',
'LBL_RULE'=>'Rule',
'LBL_SETUP'=>'Setup',
'LBL_CONFIGURE'=>'Configure',
'LBL_MAILBOX' => 'Mailbox',
'LBL_INFORMATION' => 'Information',
'LBL_SCANNER' => 'Scanner',
'LBL_SERVER'  => 'Server',
'LBL_PROTOCOL'=> 'Protocol',
'LBL_PASSWORD'=> 'Password',
'LBL_TYPE' => 'Type',
'LBL_SSL' => 'SSL',
'LBL_METHOD'=> 'Method',
'LBL_VAL_SSL_CERT'=>'Validate SSL Certificate',
'LBL_DONOT_VAL_SSL_CERT'=>'Do Not Validate SSL Certificate',
'LBL_STATUS'=>'Status',
'LBL_ENABLE'=>'Enable',
'LBL_DISABLE'=>'Disable',
'LBL_CONNECT'=>'Connect',
'LBL_URL_CAPS'=>'URL',
'LBL_ENABLED'=>'Enabled',
'LBL_DISABLED'=>'Disabled',
'LBL_RULES'=>'Rules',
'LBL_FOR'=>'For',

'LBL_FROM'=>'From',
'LBL_TO'=>'To',

'LBL_ACTION'=>'Action',
'LBL_CREATE'=>'Create',
'LBL_TICKET'=>'Ticket',
'LBL_ADD'=>'Add',

'LBL_CONTACT'=>'Contact',
'LBL_ACCOUNT'=>'Account',

'LBL_FROM_CAPS'=>'FROM',
'LBL_TO_CAPS'=>'TO',
'LBL_TO_SMALL'=>'to',

'LBL_CONTAINS'=>'Contains',
'LBL_EQUALS'=>'Equals',

'LBL_BEGINS'=>'Begins',

'LBL_REGEX'=>'Regex',
'LBL_ENDS'=>'Ends',
'LBL_BODY'=>'Body',

'LBL_NOT'=>'Not',

'LBL_ALL' => 'All',
'LBL_ANY'=>'Any',
'LBL_CONDITION'=>'Condition',
'LBL_ACTION'=>'Action',
'LBL_MOVE'=>'Move',
'LBL_UP'=>'Up',
'LBL_DOWN'=>'Down',
'LBL_PRIORITY'=>'Priority',
'LBL_UPDATE'=>'Update',
'LBL_SELECT'=>'Select',
'LBL_FOLDERS'=>'Folders',
'LBL_UNSELECT'=>'Unselect',
'LBL_MATCH'=>'Match',
'LBL_SCANNING'=>'Scanning',
'LBL_LOOKFOR'=>'Look for',
'LBL_UNREAD'=>'Unread',
'LBL_READ'=>'Read',
'LBL_AFTER_SCAN'=>'After scan',
'LBL_MESSAGES_FROM_LASTSCAN'=>'Messages from lastscan',
'LBL_MARK_MESSAGE_AS'=>'Mark message as',

//Added for the workflow module
'LBL_LIST_WORKFLOWS'=>'Workflows',
'LBL_LIST_WORKFLOWS_DESCRIPTION' => 'Create and edit workflows for vtiger',
'LBL_TASK_TITLE'=>'Task Title',
'LBL_PARENT_WORKFLOW'=>'Parent Workflow',
'MSG_EXECUTE_TASK_DELAY'=>'Execute the task after some delay',
'LBL_AFTER'=>'After',
'LBL_BEFORE'=>'Before',
'LBL_TASK_OPERATIONS'=>'Task Operations',
'LBL_CREATE_TASK'=>'Create Task',
'LBL_CREATE_TASK_OF_TYPE'=>'Create a new task of type',
'LBL_SUMMARY'=>'Summary',
'LBL_WHEN_TO_RUN_WORKFLOW'=>'When to run the workflow',
'LBL_ONLY_ON_FIRST_SAVE'=>'Only on the first save',
'LBL_UNTIL_FIRST_TIME_CONDITION_TRUE'=>'Until the first time the condition is true',
'LBL_EVERYTIME_RECORD_SAVED'=>'Every time the record is saved',
'LBL_ON_MODIFY' => 'Every time a record is modified',
'LBL_CONDITIONS'=>'Conditions',
'LBL_NEW_CONDITION_BUTTON_LABEL'=>'New Condition',
'LBL_TASKS'=>'Tasks',
'LBL_NEW_TASK_BUTTON_LABEL'=>'New Task',
'LBL_TASK'=>'Task',
// END
//Added for vantage customization (Mandatory fields) -- Pavani
'LBL_MANDATORY_FIELDS'=>'Mandatory Fields',
'LBL_MANDATORY_FIELDS_DESCRIPTION'=>'Manage mandatory fields of all modules',
// Module Sequence Numbering
'LBL_CUSTOMIZE_MODENT_NUMBER'=>'Customize Record Numbering',
'LBL_CUSTOMIZE_MODENT_NUMBER_DESCRIPTION'=>'Module Entity Number customization',
// END

//added for softphone integration
'LBL_SOFTPHONE_SERVER_SETTINGS'=>'SoftPhone Server Settings',
'LBL_SOFTPHONE_SERVER_SETTINGS_DESCRIPTION'=>'Configure your softphone here',
'ASTERISK_SERVER_IP'=>'Asterisk server IP ',
'ASTERISK_PORT'=>'Asterisk server port',
'ASTERISK_USERNAME'=>'Asterisk username',
'ASTERISK_PASSWORD'=>'Asterisk password',
'ASTERISK_SERVER_IP_TITLE'=>'The URL of the asterisk server',
'ASTERISK_PORT_TITLE'=>'The port where asterisk call manager API can connect to Asterisk (default 5038)',
'ASTERISK_USERNAME_TITLE'=>'The asterisk username (generally the admin username)',
'ASTERISK_PASSWORD_TITLE'=>'Password for the asterisk user',
'LBL_CANCEL_BUTTON'=>'Cancel',
'ASTERISK_VERSION' => 'Asterisk Version',
'ASTERISK_VERSION_TITLE'=>'Select your Asterisk version here; leave it as 1.4 if not sure',
'ASTERISK_CONFIGURATION'=>'Asterisk Configuration',
//softphone integration ends
'LBL_SELECT_FIELD_TO_MOVE' => 'Select Fields to move',
'VTLIB_LBL_SELECT_PACKAGE_FILE'=>'Select the Package File',
'VTLIB_LBL_FILE_LOCATION'=>'File location:',
'VTLIB_LBL_PACKAGE_FILE_HELP'=>'vtiger module is packaged as a zip file.',
'VTLIB_LBL_IMPORT_FAILURE'=>'Import Failure',
'VTLIB_LBL_INVALID_FILE'=>'Invalid file',
'VTLIB_LBL_INVALID_IMPORT_TRY_AGAIN'=>'provided for module import! Try Again.',
'VTLIB_LBL_UNABLE_TO_UPLOAD'=>'Unable to upload',
'VTLIB_LBL_UNABLE_TO_UPLOAD2'=>'the package on the server! Try Again.',
'VTLIB_LBL_VERIFY_IMPORT_DETAILS'=>'Verify Import Details',
'VTLIB_LBL_MODULE_NAME'=>'Module Name',
'VTLIB_LBL_MODULE_DIR'=>'Module Directory',
'VTLIB_LBL_REQ_VTIGER_VERSION'=>'Req. vtiger version',
'VTLIB_LBL_LICENSE'=>'License',
'VTLIB_LBL_LICENSE_ACCEPT_AGREEMENT'=>'I accept the license agreement.',
'VTLIB_LBL_PROCEED_WITH_IMPORT'=>'Do you want to proceed with the import?',
'VTLIB_LBL_IMPORTING_MODULE_START'=>'Importing Module ...',
'VTLIB_LBL_WARNING'=>'Warning',
'VTLIB_LBL_NOT_WRITEABLE'=>'not writeable',
'VTLIB_LBL_PACKAGE_VERSION'=>'Version',

'LBL_UPGRADE'=>'Upgrade',
'VTLIB_LBL_UPDATE_FAILURE'=>'Upgrade Failure',
'VTLIB_LBL_MODULENAME_MISMATCH'=>'Module name mistmach',
'VTLIB_LBL_TRY_AGAIN'=>'Try Again',
'VTLIB_LBL_VERIFY_UPDATE_DETAILS'=>'Verify Upgrade Details',
'VTLIB_LBL_PROCEED_WITH_UPDATE'=>'Do you want to proceed with the upgrade?',
'VTLIB_LBL_UPDAING_MODULE_START'=>'Updating module...',
'VTLIB_LBL_EXISTS'=>'Exists',
'VTLIB_LBL_NOT_PRESENT'=>'Not Present',
'VTLIB_LBL_INST_VERSION'=>'Installed Version',
'VTLIB_LBL_MATCHES_PACKAGE_VERSION'=>'matches Package Version',
'VTLIB_LBL_CANNOT_UPGRADE'=>'Cannot upgrade!',
// END

//User group fixes
'LBL_USERNAME_EXIST' => 'A User in the specified name Already Exists!',
'LBL_GROUPNAME_EXIST' => 'A Group in the specified name Already Exists!',
'LBL_ROLENAME_EXIST' => 'Role name already exists',

//layout editor
'LBL_MOVE_FIELDS' => 'Move Fields',
'NO_HIDDEN_FIELDS' => 'No Hidden Fields',
'LBL_RELATED_LIST' => 'Related List',
'LBL_ADD_BLOCK' => 'Add Block',
'HIDDEN_FIELDS' => 'Hidden Fields',
'DOWN'=> 'Down',
'UP'=> 'Up',
'RIGHT' => 'Right',
'LEFT' => 'Left',
'LBL_EDIT_PROPERTIES' => 'Edit Properties',
'LBL_MANDATORY_FIELD' => 'Mandatory Field',
'LBL_ACTIVE' => 'Active',
'LBL_QUICK_CREATE' => 'Quick Create',
'LBL_MASS_EDIT' => 'Mass Edit',
'LBL_BLOCK_NAME' => 'Block name',
'AFTER' => 'After',
'ADD_BLOCK' => 'Add Block',
'ARRANGE_RELATEDLIST' => 'Arrange RelatedList',
'CUSTOMFIELD_MAPPING' => 'CustomField Mapping',
'LBL_MAPPED_FIELDS' => 'Mapped Fields',
'LEADS_CUSTOM_FIELD_MAPPING_DESCRIPTION' => 'Map Your Leads Customfields with Accounts,Contacts and Potentials',
'LEADS_CUSTOM_FIELD_MAPPING'=> 'Leads CustomField Mapping',
'LBL_CALENDER_CUSTOMFIELDS' => 'Calendar Custom Fields',
'LBL_CALENDER_CUSTOMFIELDS_DESCRIPTION' => 'You can Create Custom Fields for Calendar',
'LBL_GO_BACK'=>'Go Back',

//Added fix for: 5418
'LBL_USE_PREFIX' => 'Use Prefix',
'LBL_START_SEQ' => 'Start Sequence',
'LBL_MODULE_NUMBERING' => 'Module Numbering',
'LBL_FAILED' => 'Failed',
'LBL_DONE' => 'Done',
'LBL_IN_USE' => 'IN USE',
'LBL_MODULE_NUMBERING_FIX_MISSING' => 'Update Missing Record Sequence Now',

//Added for: 5473
'LBL_SHARING_ACCESS_HELPNOTE' => 'After making modifications, press Recalculate button to apply the changes.',

//for customer portal extension module
'PORTAL_EXTENSION_DESCRIPTION'=>'Allows you to Configure Customer Portal Plugin',
'LBL_CUSTOMER_PORTAL'=> 'Customer Portal',

'LBL_ADD_CUSTOMFIELD' => 'Add Custom Field',

'ERR_INVALID_PROFILE_ID' => 'Invalid Profile Id. Please specify valid Profile Id',

// Customization
'LBL_PUBLISHER' => 'Publisher',
'LBL_PUBLISHED_ON' => 'Published On',
'LBL_LICENSE'   => 'License',
'LBL_EXTENSION_FILE_DOWNLOAD_FAILED' => 'Failed to download the extension package!',
'LBL_DEFAULT'=>'By default, SMTP account settings for the outgoing server are configured to od1.vtiger.com mail server. To avoid outgoing emails getting filtered out by spam filters on your recipient ISP mail server, we recommend you implement one of the following.',
'LBL_OPTIONS1'=>'Send emails from your mail server<br>
				- Enter the SMTP account details (Server Name, User Name, Password) for the same account as entered in the FROM email address.',
'LBL_OPTIONS2'=>"Add od1.vtiger.com server as a authorized sender for your domain.<br>
				- If you prefer to retain the vtiger server as the outgoing server, we recommend that you configure your domain's SPF record to include the vtiger server as a valid sender for your domain.
				  For additonal instruction on setting up SPF record, please email od-support@vtiger.com .",
'LBL_ALREADY_EXISTS' => 'Already Exists',
'LBL_EXTENSION_INCOMPATIBLE' => 'Extension Incompatible',
'LBL_INSTALL' => 'Install',
'LBL_DEFAULT_SETTINGS_BUTTON_TITLE' => 'Reset To Default',
'LBL_CONFIRM_DEFAULT_SETTINGS' => 'Are you sure that you want to change the server details to the default server values',
'EXISTING_DEFAULT_VALUES' => 'The server details are already set to the default values',
'LBL_NOTE' => 'Note:',
'LBL_HIDE' => 'Hide Details',
'LBL_SHOW' => 'Show Details',
// END
'LBL_USER_ADDITION_INFO'=>"To add a new user, please click on  
			   <span style='font-style:italic;color:blue;'>OD-Settings Menu -> On Demand Admin -> Add User </span>",

'LBL_READ_ONLY_ACCESS_MSG' => 'Read-Only Access',
'LBL_READ_WRITE_ACCESS_MSG' => 'Read-Write Access',

'LBL_DEFAULT_VALUE' => 'Default Value',

'LBL_DESCRIPTION_Public: Read Only'=>'Users can Read Only other users ',
'LBL_DESCRIPTION_Public: Read, Create/Edit'=>'Users can Read, Create/Edit other users ',
'LBL_DESCRIPTION_Public: Read, Create/Edit, Delete'=>'Users can Read, Create/Edit, Delete other users ',

// For Dependency picklist
'LBL_PICKLIST_DEPENDENCY_SETUP' => 'Picklist Dependency Setup',
'LBL_PICKLIST_DEPENDENCY_DESCRIPTION' => 'Setup Dependency between Picklist values in each module',

'Settings' => 'Settings',
'LBL_ERR_TAX_LABEL_ALREADY_EXISTS' => 'This tax is already available.',
'LBL_ERR_SOME_TAX_LABELS_ALREADY_EXISTS' => 'Some tax labels are already available, hence not saved.',
);
?>